@@ -161,7 +161,7 @@ class Vehicle(object):
             _LOGGER.debug("401 response while refreshing token")
             self.auth()
         else:
-            _LOGGER.debug(f"Refresh Token method did not return a 200 or 401 response. The response returned was: {response.text}")
+            _LOGGER.debug(f"Refresh Token method did not return a 200 or 401 response. The response code returned was: {response.status_code} and the message was: {response.text}")
     
     def writeToken(self, token):
         _LOGGER.debug("Write Token method called.")
